REQUEST = 'request'
TEXT = 'text'
JSON = 'application/json'
PASSED = 'PASSED'
FAILED = 'FAILED'
PROVIDER_STATE = 'providerState'
TEST_PARENT = 'ServiceConsumerTest'
MISSING_STATE = 'Missing implementation for state '
MISSING_PACT_HELPER = 'Missing "pact_helper.py" at "'
MISSING_PACT_URI = 'Missing setup for "pact_uri" at '
MISSING_TESTS = 'There are no consumer tests to verify.'
MISSING_SETUP = 'Missing "setup" method in "pact_helper.py".'
MISSING_HAS_PACT_WITH = 'Missing setup for "has_pact_with" at '
MISSING_TEAR_DOWN = 'Missing "tear_down" method in "pact_helper.py".'
EXTEND_PACT_HELPER = 'Pact Helper class must extend pact_test.PactHelper'
